<?php
/*
*  @author Denis Sitko  <info@sitkodenis.ru>
*  @copyright  2015 Denis Sitko
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*/
if (!defined('_CAN_LOAD_FILES_'))
	exit;

class BlockCheckSpelling extends Module
{
	public function __construct()
	{
		$this->name = 'blockcheckspelling';
		$this->tab = 'front_office_features';
		$this->version = '1.0';
		$this->author = 'Denis Sitko';
		$this->controllers = ['form', 'senderror'];
		$this->need_instance = 0;
		$this->bootstrap = true;

		parent::__construct();

		$this->displayName = $this->l('Error in the text');
		$this->description = $this->l('Sending a visitor notices an error on the site.');
		$this->ps_versions_compliancy = ['min' => '1.6', 'max' => _PS_VERSION_];
	}

	public function install($delete_params = true)
	{
		if (!parent::install() || !$this->registerHook('header') || !$this->registerHook('displayCheckSpelling'))
			return false;

		if ($delete_params)
		{
			Configuration::updateValue('BLOCKCHECKSPELLING_EMAIL', Configuration::get('PS_SHOP_EMAIL'));
		}

		return true;
	}

	public function uninstall($delete_params = true)
	{
		if ($delete_params)
		{
			Configuration::deleteByName('BLOCKCHECKSPELLING_EMAIL');
		}

		return parent::uninstall();
	}

	public function hookHeader($params)
	{
		$this->context->controller->addCss($this->_path . '/css/blockcheckspelling.css');
		$this->context->controller->addJqueryPlugin('fancybox');
	}

	public function hookDisplayCheckSpelling($params)
	{
		return $this->display(__FILE__, 'block.tpl');
	}

	public function hookAjaxForm()
	{
		return $this->display(__FILE__, 'form.tpl');
	}

	public function getContent()
	{
		$errors = [];
		$output = null;

		if (Tools::isSubmit('submit'.$this->name))
		{
			if (!Configuration::updateValue('BLOCKCHECKSPELLING_EMAIL', (string)Tools::getValue('BLOCKCHECKSPELLING_EMAIL')))
				$errors[] = $this->l('Cannot update settings');

			if (count($errors) > 0)
				$output .= $this->displayError(implode('<br />', $errors));
			else
				$output .= $this->displayConfirmation($this->l('Settings updated successfully'));
		}

		return $output.$this->displayForm();
	}

	public function displayForm()
	{
		$default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

		$fields_form[0]['form'] = [
			'legend' => [
				'title' => $this->l('Settings'),
				'icon' => 'icon-cog'
			],
			'input' => [
				[
					'type' => "text",
					'name' => 'BLOCKCHECKSPELLING_EMAIL',
					'label' => $this->l('Email'),
				],
			],
			'submit' => [
				'title' => $this->l('Save'),
				'class' => 'btn btn-default pull-right'
			]
		];

		$helper = new HelperForm();

		$helper->module = $this;
		$helper->name_controller = $this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

		$helper->default_form_language = $default_lang;
		$helper->allow_employee_form_lang = $default_lang;

		$helper->title = $this->displayName;
		$helper->show_toolbar = true;
		$helper->toolbar_scroll = true;
		$helper->submit_action = 'submit'.$this->name;

		$helper->toolbar_btn = [
			'save' =>
				[
					'desc' => $this->l('Save'),
					'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
						'&token='.Tools::getAdminTokenLite('AdminModules'),
				]
		];

		$helper->fields_value['BLOCKCHECKSPELLING_EMAIL'] = (string)Configuration::get('BLOCKCHECKSPELLING_EMAIL');

		return $helper->generateForm($fields_form);
	}

	public function sendError($errorText)
	{
		$template_vars = array(
			'{errorText}' => Tools::safeOutput($errorText),
			'{shop_name}' => Configuration::get('PS_SHOP_NAME'),
			'{date}' => date('d.m.Y H:i:s')
		);

		return Mail::Send($this->context->language->id,
			'blockcheckspelling',
			'Орфографическая ошибка на сайте',
			$template_vars,
			Configuration::get('BLOCKCHECKSPELLING_EMAIL'),
			null,
			Configuration::get('PS_SHOP_EMAIL'),
			Configuration::get('PS_SHOP_NAME'),
			null,
			null,
			dirname(__FILE__).'/mails/',
			false,
			$this->context->shop->id
		);
	}
}